using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;
using System.Web.Mvc.Ajax;
using ImageGallery.Models;

namespace ImageGallery.Controllers
{
    [HandleError]
    public class GalleryController : Controller
    {
        public ActionResult Index()
        {
            GalleryDataContext context = new GalleryDataContext();
            List<GalleryImage> images = context.GetImages();

            return View(images);
        }

        public ActionResult Detail(int id)
        {
            GalleryDataContext context = new GalleryDataContext();
            var image = context.GetImageById(id);

            return View(image);
        }

        [AcceptVerbs(HttpVerbs.Get)]
        public ActionResult Create()
        {
            return View();
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Create(GalleryImage image)
        {
            try
            {
                // Controllo che tutti i campi richiesti siano stati inseriti dall'utente
                if (string.IsNullOrEmpty(image.FileName))
                    ModelState.AddModelError("FileName", "Nome richiesto");

                if (string.IsNullOrEmpty(image.FileExtension))
                    ModelState.AddModelError("FileExtension", "Estensione richiesta");

                if (ModelState.IsValid)
                {
                    // Tutto ok, aggiungo la nuova immagine al database
                    GalleryDataContext context = new GalleryDataContext();
                    context.GalleryImages.InsertOnSubmit(image);
                    context.SubmitChanges();

                    // Reindirizzo l'utente all'immagine appena aggiunta
                    return RedirectToAction("Detail", new { id = image.ImageId });
                }
            }
            catch (Exception ex)
            {
                // Si  verificato qualche errore
                ModelState.AddModelError("Errore", ex);
            }

            // Mostro di nuovo la vista
            return View();
        }

        [AcceptVerbs(HttpVerbs.Get)]
        public ActionResult Edit(int id)
        {
            GalleryDataContext context = new GalleryDataContext();
            var image = context.GetImageById(id);

            return View(image);
        }

        [AcceptVerbs(HttpVerbs.Post)]
        public ActionResult Edit(int id, FormCollection values)
        {
            try
            {
                // Controllo che tutti i campi richiesti siano stati inseriti dall'utente
                if (string.IsNullOrEmpty(values["FileName"]))
                    ModelState.AddModelError("FileName", "Nome richiesto");

                if (string.IsNullOrEmpty(values["FileExtension"]))
                    ModelState.AddModelError("FileExtension", "Estensione richiesta");

                if (ModelState.IsValid)
                {
                    // Tutto ok, aggiorno l'immagine
                    GalleryDataContext context = new GalleryDataContext();
                    GalleryImage image = context.GetImageById(id);

                    if (image == null)
                        throw new Exception("Immagine non trovata.");

                    UpdateModel<GalleryImage>(image);
                    context.SubmitChanges();

                    // Reindirizzo l'utente all'immagine aggiornata
                    return RedirectToAction("Detail", new { id = image.ImageId });
                }
            }
            catch (Exception ex)
            {
                // Si  verificato qualche errore
                ModelState.AddModelError("Errore", ex);
            }

            // Mostro di nuovo la vista
            return View();
        }
    }
}
